@@ -1,7 +1,7 @@
 """
 Type annotations for chime-sdk-meetings service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/literals/)
 
 Usage::
 
@@ -35,6 +35,7 @@ __all__ = (
     "ChimeSDKMeetingsServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -199,6 +200,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -300,6 +302,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -396,3 +399,4 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal["ap-southeast-1", "eu-central-1", "us-east-1", "us-west-2"]
